pub enum BpeError {
InvalidMergeEntry(String),
InvalidVocabEntry(String),
MissingVocabEntry(String),
}Expand description
Errors that can occur when building a Bpe tokenizer or encoding or
decoding text using it.
Variants
InvalidMergeEntry(String)
There was an invalid entry in the merge list. This means that either
the entry doesn’t have the expected <token> [SPACE] <token> format
or the <token> is not either a single character or the concatenation
of another pair in the merge list.
InvalidVocabEntry(String)
An entry in the vocab (token string to ID map) is not either a known special token or an entry in the merge list.
MissingVocabEntry(String)
An entry was not found in the vocabulary.