EncodedByteSlice

Type Alias EncodedByteSlice 

pub type EncodedByteSlice<'a> = &'a str;
A sequence of UTF-8 bytes, encoded as a string of printable characters. char_to_byte provides the mapping between characters and bytes.

Unlike a Rust str, the sequence of bytes do not necessarily form a complete sequence of Unicode characters. The bytes may end in the middle of a character.