pub struct BertOptions {
pub lowercase: bool,
pub strip_accents: bool,
}Expand description
Configuration for a Bert normalizer.
Fields
lowercase: boolIf true, convert all text to lowercase using char::to_lowercase.
strip_accents: boolWhether to strip accents when tokenizing. An “accent” is defined as any unicode character in the Nonspacing Mark (“Mn”) category.